﻿<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ms="urn:schemas-microsoft-com:xslt">

  <!-- Dependencies/Uses -->
  <xsl:template match="Uses">
    <xsl:param name="objectType" />
    <xsl:param name="content" />
    <xsl:param name="ext" />

    <xsl:choose>
      <xsl:when test="./*">
                <div class="collapsible" data-key="uses">
          <div class="collapsible-link font-large font-bold">Uses</div>
          <div class="collapsible-area">
        <table class="table">
          <thead>
            <tr>
              <th>Name</th>
            </tr>
          </thead>
          <tbody>
            <xsl:apply-templates select="Dependency">
              <xsl:with-param name="objectType" select="$objectType"/>
              <xsl:with-param name="content" select="$content"/>
              <xsl:with-param name="ext" select="$ext"/>
              <xsl:with-param name="nestingLevel" select="0"/>
            </xsl:apply-templates>
          </tbody>
        </table>
          </div>
        </div>
      </xsl:when>
    </xsl:choose>
  </xsl:template>

  <!-- Dependencies/UsedBy -->
  <xsl:template match="UsedBy">
    <xsl:param name="objectType" />
    <xsl:param name="content" />
    <xsl:param name="ext" />

    <xsl:choose>
      <xsl:when test="./*">
          <div class="collapsible" data-key="used-by">
          <div class="collapsible-link font-large font-bold">Used by</div>
          <div class="collapsible-area">
        <table class="table">
          <thead>
            <tr>
              <th>Name</th>
            </tr>
          </thead>
          <tbody>
            <xsl:apply-templates select="Dependency">
              <xsl:with-param name="objectType" select="$objectType"/>
              <xsl:with-param name="content" select="$content"/>
              <xsl:with-param name="ext" select="$ext"/>
              <xsl:with-param name="nestingLevel" select="0"/>
            </xsl:apply-templates>
          </tbody>
        </table>
          </div>
        </div>
      </xsl:when>
    </xsl:choose>
  </xsl:template>

  <!-- Dependency -->
  <xsl:template match="Dependency">
    <xsl:param name="objectType" />
    <xsl:param name="content" />
    <xsl:param name="ext" />
    
    <xsl:param name="nestingLevel" />

    <xsl:variable name="styleDisplay">
      <xsl:choose>
        <xsl:when test="$nestingLevel = 0">font-weight: bold</xsl:when>
        <xsl:when test="$nestingLevel > 1">display: none</xsl:when>
        <xsl:otherwise></xsl:otherwise>
      </xsl:choose>
    </xsl:variable>

    <xsl:variable name="colspan">
      <xsl:choose>
        <xsl:when test="$nestingLevel = 0">2</xsl:when>
        <xsl:otherwise></xsl:otherwise>
      </xsl:choose>
    </xsl:variable>

    <tr class="dependency-node" style="{$styleDisplay}" data-node-id="{NodeId}" data-parent-node-id="{NodeParentId}">
      <td>
        <div style="margin-left: {$nestingLevel * 22}px">
          <div style="float: left">
            <xsl:variable name="icon">
              <xsl:choose>
                <xsl:when test="ObjectType = 'TABLE'"> icon-table </xsl:when>
                <xsl:when test="ObjectType = 'VIEW'"> icon-view </xsl:when>
                <xsl:when test="ObjectType = 'PROCEDURE'"> icon-procedure </xsl:when>
                <xsl:when test="ObjectType = 'FUNCTION'"> icon-function </xsl:when>
                <xsl:when test="ObjectType = 'TRIGGER'"> icon-trigger-active </xsl:when>
                <xsl:when test="ObjectType = 'TRIGGER_DISABLED'"> icon-trigger-disabled </xsl:when>
                <xsl:when test="ObjectType = 'UNRESOLVED_ENTITY'"> icon-unresolved-entity </xsl:when>
              </xsl:choose>
            </xsl:variable>

            <xsl:choose>
              <xsl:when test="./Uses/Dependency or ./UsedBy/Dependency">

                <xsl:choose>
                  <xsl:when test="$nestingLevel > 0">
                    <span class="expand">
                      <i class="icon-expand"></i>
                    </span>
                    <span class="collapse" style="display: none">
                      <i class="icon-collapse"></i>
                    </span>
                  </xsl:when>
                  <xsl:otherwise>
                    <span class="expand" style="display: none">
                      <i class="icon-expand"></i>
                    </span>
                    <span class="collapse">
                      <i class="icon-collapse"></i>
                    </span>
                  </xsl:otherwise>
                </xsl:choose>
              </xsl:when>
              <xsl:otherwise>
                <span>
                  <i class="icon-none"></i>
                </span>
              </xsl:otherwise>
            </xsl:choose>

            <i class="{$icon}"></i>
          </div>
          <div style="margin-left: 44px;">
            <xsl:call-template name="dependencyLink">
              <xsl:with-param name="objectType" select="$objectType"/>
              <xsl:with-param name="content" select="$content"/>
              <xsl:with-param name="ext" select="$ext"/>
            </xsl:call-template>
          </div>
        </div>
      </td>
    </tr>

    <xsl:apply-templates select="Uses/Dependency">
      <xsl:with-param name="objectType" select="$objectType"/>
      <xsl:with-param name="content" select="$content"/>
      <xsl:with-param name="ext" select="$ext"/>

      <xsl:with-param name="nestingLevel" select="$nestingLevel + 1"/>
    </xsl:apply-templates>
    <xsl:apply-templates select="UsedBy/Dependency">
      <xsl:with-param name="objectType" select="$objectType"/>
      <xsl:with-param name="content" select="$content"/>
      <xsl:with-param name="ext" select="$ext"/>

      <xsl:with-param name="nestingLevel" select="$nestingLevel + 1"/>
    </xsl:apply-templates>
  </xsl:template>
  
  <!-- Link for dependency (for object other than current only) -->
  <xsl:template name="dependencyLink">
    <xsl:param name="objectType" />
    <xsl:param name="content" />
    <xsl:param name="ext" />
      
    <xsl:choose>
      <xsl:when test="IsExported = 'Yes' and IsSameObject = 'No' and
        ((not(ParentObjectIdString) and
          (/DataDocumenter/Table/ObjectId != '' and ObjectIdString != /DataDocumenter/Table/ObjectId) or
          (/DataDocumenter/View/ObjectId != '' and ObjectIdString != /DataDocumenter/View/ObjectId) or
          (/DataDocumenter/Procedure/ObjectId != '' and ObjectIdString != /DataDocumenter/Procedure/ObjectId) or
          (/DataDocumenter/Function/ObjectId != '' and ObjectIdString != /DataDocumenter/Function/ObjectId))
        or
        (ParentObjectIdString and
          (/DataDocumenter/Table/ObjectId != '' and ParentObjectIdString != /DataDocumenter/Table/ObjectId) or
          (/DataDocumenter/View/ObjectId != '' and ParentObjectIdString != /DataDocumenter/View/ObjectId) or
          (/DataDocumenter/Procedure/ObjectId != '' and ParentObjectIdString != /DataDocumenter/Procedure/ObjectId) or
          (/DataDocumenter/Function/ObjectId != '' and ParentObjectIdString != /DataDocumenter/Function/ObjectId)))">

        <xsl:choose>
          <xsl:when test="IsInCurrentModule='Yes'">

            <xsl:variable name="moduleObjectId">
              <xsl:choose>
                <xsl:when test="$objectType = 'Table'">
                  <xsl:value-of select="/DataDocumenter/Table/ModuleObjectId"/>
                </xsl:when>
                <xsl:when test="$objectType = 'View'">
                  <xsl:value-of select="/DataDocumenter/View/ModuleObjectId"/>
                </xsl:when>
                <xsl:when test="$objectType = 'Procedure'">
                  <xsl:value-of select="/DataDocumenter/Procedure/ModuleObjectId"/>
                </xsl:when>
                <xsl:when test="$objectType = 'Function'">
                  <xsl:value-of select="/DataDocumenter/Function/ModuleObjectId"/>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:value-of select="''"/>
                </xsl:otherwise>
              </xsl:choose>
            </xsl:variable>
            
            <xsl:choose>
              <xsl:when test="ObjectType = 'TABLE' and $moduleObjectId != ''">
                <a href="#{$root}/{ObjectDatabaseIdString}/modules/{$moduleObjectId}/tables/{ObjectIdString}{$ext}" class="ajax" data-target="#right">
                  <xsl:value-of select="ObjectFullName"/>
                </a>
              </xsl:when>
              <xsl:when test="ObjectType = 'VIEW' and $moduleObjectId != ''">
                <a href="#{$root}/{ObjectDatabaseIdString}/modules/{$moduleObjectId}/views/{ObjectIdString}{$ext}" class="ajax" data-target="#right">
                  <xsl:value-of select="ObjectFullName"/>
                </a>
              </xsl:when>
              <xsl:when test="ObjectType = 'PROCEDURE' and $moduleObjectId != ''">
                <a href="#{$root}/{ObjectDatabaseIdString}/modules/{$moduleObjectId}/procedures/{ObjectIdString}{$ext}" class="ajax" data-target="#right">
                  <xsl:value-of select="ObjectFullName"/>
                </a>
              </xsl:when>
              <xsl:when test="ObjectType = 'FUNCTION' and $moduleObjectId != ''">
                <a href="#{$root}/{ObjectDatabaseIdString}/modules/{$moduleObjectId}/functions/{ObjectIdString}{$ext}" class="ajax" data-target="#right">
                  <xsl:value-of select="ObjectFullName"/>
                </a>
              </xsl:when>
              <xsl:when test="ObjectType = 'TRIGGER' and $moduleObjectId != ''">
                <a href="#{$root}/{ObjectDatabaseIdString}/modules/{$moduleObjectId}/tables/{ParentObjectIdString}{$ext}" class="ajax" data-target="#right">
                  <xsl:value-of select="ObjectFullName"/>
                </a>
              </xsl:when>
              <xsl:otherwise>
                <xsl:value-of select="ObjectFullName"/>
              </xsl:otherwise>
            </xsl:choose>

          </xsl:when>
          <xsl:otherwise>

            <xsl:choose>
              <xsl:when test="ObjectType = 'TABLE'">
                <a href="#{$root}/{ObjectDatabaseIdString}/tables/{ObjectIdString}{$ext}" class="ajax" data-target="#right">
                  <xsl:value-of select="ObjectFullName"/>
                </a>
              </xsl:when>
              <xsl:when test="ObjectType = 'VIEW'">
                <a href="#{$root}/{ObjectDatabaseIdString}/views/{ObjectIdString}{$ext}" class="ajax" data-target="#right">
                  <xsl:value-of select="ObjectFullName"/>
                </a>
              </xsl:when>

              <xsl:when test="ObjectType = 'PROCEDURE'">
                <a href="#{$root}/{ObjectDatabaseIdString}/procedures/{ObjectIdString}{$ext}" class="ajax" data-target="#right">
                  <xsl:value-of select="ObjectFullName"/>
                </a>
              </xsl:when>
              <xsl:when test="ObjectType = 'FUNCTION'">
                <a href="#{$root}/{ObjectDatabaseIdString}/functions/{ObjectIdString}{$ext}" class="ajax" data-target="#right">
                  <xsl:value-of select="ObjectFullName"/>
                </a>
              </xsl:when>
              <xsl:when test="ObjectType = 'TRIGGER'">
                <a href="#{$root}/{ObjectDatabaseIdString}/tables/{ParentObjectIdString}{$ext}" class="ajax" data-target="#right">
                  <xsl:value-of select="ObjectFullName"/>
                </a>
              </xsl:when>
              <xsl:otherwise>
                <xsl:value-of select="ObjectFullName"/>
              </xsl:otherwise>
            </xsl:choose>

          </xsl:otherwise>
        </xsl:choose>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="ObjectFullName"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!-- Scripts for dependencies -->
  <xsl:template name="dependenciesScripts">
    <xsl:param name="resources" />

    <script src="{$resources}js/dependenciesTree.js"></script>  
  </xsl:template>

  <xsl:template name="applyDependenciesEvents">
    <script>
      $('.dependency-node .expand').click(function () {
        expand(this, true);
      });

      $('.dependency-node .collapse').click(function () {
        collapse(this, true);
      });
    </script>
  </xsl:template>
</xsl:stylesheet>